% pop_remove_event_data() - Remove continuous data intervals associated
% with specific events and their duration
% Useful for removing intervals that are defined by individual markers
% and a number of points (duration).
% Also removes other markers within the removed time interval.
%
% Useful to delete Brain Vision Analyzer's bad data intervals.
% Outputs a continuous EEG file.
%
% This function doesn't respect phase activity! If you want to use
% this function and still compute phase information, then don't do it
% around epochs that contain the event "boundary".
%
% Usage:
%   >> OUTEEG = eeglab_remove_event_data (EEG, typerange);
%
% Inputs:
%   EEG        - Input dataset. Not tested for epoched data.
%   typerange  - Cell array of event types to time lock to.
%                (Note: An event field called 'type' must be defined in 
%                the 'EEG.event' structure).
% Outputs:
%   OUTEEG     - output dataset

% Copyright (C) 2017 Gonçalo Sampaio, gsampaio@wesleyan.edu
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

function [EEG, com] = pop_remove_event_data( EEG, typerange );

% the command output is a hidden output that does not have to
% be described in the header

com = ''; % this initialization ensure that the function will return something
          % if the user press the cancel button            

% display help if not enough arguments
% ------------------------------------
if nargin < 1

	help pop_remove_event_data;
	error('Must include an EEG dataset as argument.')
	return;
end;	

% pop up window
% -------------
if nargin < 2
	promptstr    = [{ 'Specifiy the type of the events around which is the data you want to delete:' },{''},{''}];
	% inistr       = { '0' };
	typelist = unique({EEG.event.type});
	[typerange, ok] = listdlg('PromptString',promptstr,...
					  	      'ListString',typelist);
	if ok == 1 return; end;
end;

% call function sample either on raw data or ICA data
% ---------------------------------------------------
remove_event_data(EEG, typerange);

% return the string command
% -------------------------
com = sprintf('pop_remove_event_data( %s, [%s] );', inputname(1), int2str(typerange));

return;
